@@ -1,5 +1,8 @@
 import math
+import random
 import re
+import sys
+from hashlib import sha1
 
 from flask import abort, request, render_template
 from peewee import Model, DoesNotExist, SelectQuery
@@ -47,3 +50,23 @@ def get_next():
 
 def slugify(s):
     return re.sub('[^a-z0-9_\-]+', '-', s.lower())
+
+def load_class(s):
+    path, klass = s.rsplit('.', 1)
+    __import__(path)
+    mod = sys.modules[path]
+    return getattr(mod, klass)
+
+
+# borrowing these methods, slightly modified, from django.contrib.auth
+def get_hexdigest(salt, raw_password):
+    return sha1(salt + raw_password).hexdigest()
+
+def make_password(raw_password):
+    salt = get_hexdigest(str(random.random()), str(random.random()))[:5]
+    hsh = get_hexdigest(salt, raw_password)
+    return '%s$%s' % (salt, hsh)
+
+def check_password(raw_password, enc_password):
+    salt, hsh = enc_password.split('$', 1)
+    return hsh == get_hexdigest(salt, raw_password)
